using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Interactivity;
using Syncfusion.Windows.Controls.Gantt;
using Syncfusion.Windows.Controls.Grid;
using System.Windows;
using System.Windows.Media.Imaging;

namespace CustomizedTable
{
    class GridCustomizationBehavior : Behavior<GanttControl>
    {
        /// <summary>
        /// Called after the behavior is attached to an AssociatedObject.
        /// </summary>
        /// <remarks>Override this to hook up functionality to the AssociatedObject.</remarks>
        protected override void OnAttached()
        {
             AssociatedObject.Loaded += new System.Windows.RoutedEventHandler(AssociatedObject_Loaded);
        }

        /// <summary>
        /// Handles the Loaded event of the AssociatedObject control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.Windows.RoutedEventArgs"/> instance containing the event data.</param>
        void AssociatedObject_Loaded(object sender, System.Windows.RoutedEventArgs e)
        {
            /// Removing Resource Column from the Grid(Table)
            for (int i = 0; i < this.AssociatedObject.GanttGrid.Columns.Count; i++)
            {
                if (this.AssociatedObject.GanttGrid.Columns[i].MappingName == "Resource")
                {
                    /// Removing Resource Column from the Grid(Table)
                    this.AssociatedObject.GanttGrid.Columns.RemoveAt(i);
                }
            }

            /// Fetching the Progress Column from the Grid(Table)
            GridTreeColumn progColumn = this.AssociatedObject.GanttGrid.Columns[5];
            /// Changing the cell type of progress Column
            progColumn.StyleInfo = new GridStyleInfo
            {
                CellType = "UpDownEdit",
                UpDownEdit = new GridUpDownEditStyleInfo { MaxValue = 100, MinValue = 0, Step = 5 }
            };

            /// Removing and reinserting the progress column in possition 2
            this.AssociatedObject.GanttGrid.Columns.Remove(progColumn);
            this.AssociatedObject.GanttGrid.Columns.Insert(2, progColumn);
            
            /// Creating a new custom column of IsCompleted
            GridTreeColumn column1 = new GridTreeColumn
            {
                MappingName = "IsCompleted",
                HeaderText = "IsCompleted",
                StyleInfo = new GridStyleInfo
                {
                    CellType = "CheckBox",
                    HorizontalAlignment = HorizontalAlignment.Center,
                    VerticalAlignment = VerticalAlignment.Center
                }
            };
            // To customize column width
            this.AssociatedObject.GanttGrid.Model.ColumnWidths[3] = 150;

            /// Inserting the custom columns to GanttGrid(Table)
            this.AssociatedObject.GanttGrid.Columns.Insert(2, column1);
        }

        /// <summary>
        /// Called when the behavior is being detached from its AssociatedObject, but before it has actually occurred.
        /// </summary>
        /// <remarks>Override this to unhook functionality from the AssociatedObject.</remarks>
        protected override void OnDetaching()
        {
            AssociatedObject.Loaded -= new System.Windows.RoutedEventHandler(AssociatedObject_Loaded);
        }
    }
}
